# -*- coding: utf-8 -*-

# @Time    : 2020/9/8 23:48
# @Email   : 986798607@qq.com
# @Software: PyCharm
# @License: BSD 3-Clause

__all__ = ["ego", "multiplyego","base_ego"]
